import 'package:cs_resources/generated/assets.dart';
import 'package:domain/entity/garage_sale_rent_entity.dart';
import 'package:flutter/material.dart';
import 'package:auto_route/auto_route.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter_hooks/flutter_hooks.dart';
import 'package:hooks_riverpod/hooks_riverpod.dart';
import 'package:plugin_basic/provider/app_config/app_config_service.dart';
import 'package:router/ext/auto_router_extensions.dart';
import 'package:shared/utils/color_utils.dart';
import 'package:shared/utils/ext_dart.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:shared/utils/screen_util.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/my_button.dart';
import 'package:widgets/my_load_image.dart';
import 'package:widgets/ext/ex_widget.dart';
import 'package:widgets/my_text_view.dart';
import 'package:widgets/my_appbar.dart';
import 'package:cs_resources/theme/app_colors_theme.dart';
import 'package:widgets/widget_export.dart';

import '../../../constants_services.dart';
import '../../../router/page/services_page_router.dart';
import 'service_pay_success_vm.dart';
import '../../../components/status_card_item.dart';

@RoutePage()
class ServicePaySuccessPage extends HookConsumerWidget {
  final int id;
  final int serviceTypeCode;
  const ServicePaySuccessPage({
    Key? key,
    required this.id,
    required this.serviceTypeCode,
  }) : super(key: key);

  //启动当前页面
  static void startInstance({BuildContext? context, required int id, required int serviceTypeCode}) {
    if (context != null) {
      context.router.push(ServicePaySuccessPageRoute(id: id, serviceTypeCode: serviceTypeCode));
    } else {
      appRouter.push(ServicePaySuccessPageRoute(id:id, serviceTypeCode: serviceTypeCode));
    }
  }


  @override
  Widget build(BuildContext context, WidgetRef ref) {
    final vm = ref.read(servicePaySuccessVmProvider.notifier);
    final state = ref.watch(servicePaySuccessVmProvider);
    // final appConfigState = ref.watch(appConfigServiceProvider)


    useEffect(() {
      // 组件挂载时执行 - 执行接口请求
      Future.microtask(() => vm.initPageData());
      return () {
        // 组件卸载时执行
      };
    }, []);

    return Scaffold(
      // appBar: MyAppBar.appBar(
      //   context,
      //   "ServicePaySuccess",
      //   backgroundColor: context.appColors.whiteBG,
      // ),
      backgroundColor: ColorUtils.string2Color("#F2F3F6"),
      body: SizedBox(
          width: double.infinity,
          height: double.infinity,
          child: EasyRefresh(
            key: ValueKey('ServicePaySuccess'),
            controller: vm.refreshController,
            // 上拉加载
            onLoad: () async{
              Log.d("----onLoad");
              vm.loadMore();
            },
            // 下拉刷新
            onRefresh: () async{
              Log.d("----onRefresh");
              vm.onRefresh();
            },
            child: LoadStateLayout(
              state: state.loadingState,
              errorMessage: state.errorMessage,
              errorRetry: () {
                vm.retryRequest();
              },
              successWidget: Container(),
            ),
          ).marginOnly(left: 15,right: 15,top: 0,bottom: 15)
      ),
    );
  }

}